@@ -957,6 +957,23 @@ on_greeter_connected (GdmGreeterServer *greeter_server,
         }
 }
 
+static void
+on_greeter_disconnected (GdmGreeterServer *greeter_server,
+                         GdmSimpleSlave   *slave)
+{
+        gboolean display_is_local;
+
+        g_debug ("GdmSimpleSlave: Greeter disconnected");
+
+        g_object_get (slave,
+                      "display-is-local", &display_is_local,
+                      NULL);
+
+        if ( ! display_is_local) {
+                gdm_slave_stopped (GDM_SLAVE (slave));
+        }
+}
+
 static void
 on_start_session_when_ready (GdmGreeterServer *session,
                              GdmSimpleSlave   *slave)
@@ -1069,6 +1086,10 @@ start_greeter (GdmSimpleSlave *slave)
                           "connected",
                           G_CALLBACK (on_greeter_connected),
                           slave);
+        g_signal_connect (slave->priv->greeter_server,
+                          "disconnected",
+                          G_CALLBACK (on_greeter_disconnected),
+                          slave);
         g_signal_connect (slave->priv->greeter_server,
                           "cancelled",
                           G_CALLBACK (on_greeter_cancel),
